summaryrefslogtreecommitdiffstats
path: root/kopete/plugins/smpppdcs/detectornetstat.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/plugins/smpppdcs/detectornetstat.cpp')
-rw-r--r--kopete/plugins/smpppdcs/detectornetstat.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/kopete/plugins/smpppdcs/detectornetstat.cpp b/kopete/plugins/smpppdcs/detectornetstat.cpp
index f1ed21b5..6cb85d0e 100644
--- a/kopete/plugins/smpppdcs/detectornetstat.cpp
+++ b/kopete/plugins/smpppdcs/detectornetstat.cpp
@@ -39,16 +39,16 @@ void DetectorNetstat::checkStatus() const {
m_buffer = TQString();
// Use KProcess to run netstat -r. We'll then parse the output of
// netstat -r in slotProcessStdout() to see if it mentions the
// default gateway. If so, we're connected, if not, we're offline
- m_process = new KProcess;
+ m_process = new TDEProcess;
*m_process << "netstat" << "-r";
- connect(m_process, TQT_SIGNAL(receivedStdout(KProcess *, char *, int)), this, TQT_SLOT(slotProcessStdout( KProcess *, char *, int)));
- connect(m_process, TQT_SIGNAL(processExited(KProcess *)), this, TQT_SLOT(slotProcessExited(KProcess *)));
+ connect(m_process, TQT_SIGNAL(receivedStdout(TDEProcess *, char *, int)), this, TQT_SLOT(slotProcessStdout( TDEProcess *, char *, int)));
+ connect(m_process, TQT_SIGNAL(processExited(TDEProcess *)), this, TQT_SLOT(slotProcessExited(TDEProcess *)));
- if(!m_process->start(KProcess::NotifyOnExit, KProcess::Stdout)) {
+ if(!m_process->start(TDEProcess::NotifyOnExit, TDEProcess::Stdout)) {
kdWarning(14312) << k_funcinfo << "Unable to start netstat process!" << endl;
delete m_process;
@@ -56,14 +56,14 @@ void DetectorNetstat::checkStatus() const {
}
}
-void DetectorNetstat::slotProcessStdout(KProcess *, char *buffer, int buflen) {
+void DetectorNetstat::slotProcessStdout(TDEProcess *, char *buffer, int buflen) {
// Look for a default gateway
kdDebug(14312) << k_funcinfo << endl;
m_buffer += TQString::fromLatin1(buffer, buflen);
kdDebug(14312) << m_buffer << endl;
}
-void DetectorNetstat::slotProcessExited(KProcess *process) {
+void DetectorNetstat::slotProcessExited(TDEProcess *process) {
kdDebug(14312) << k_funcinfo << m_buffer << endl;
if(process == m_process) {
m_connector->setConnectedStatus(m_buffer.contains("default"));
@@ -39,16 +39,16 @@ void DetectorNetstat::checkStatus() const {
m_buffer = TQString();
- // Use KProcess to run netstat -r. We'll then parse the output of
+ // Use TDEProcess to run netstat -r. We'll then parse the output of
// netstat -r in slotProcessStdout() to see if it mentions the
// default gateway. If so, we're connected, if not, we're offline